@@ -9,31 +9,29 @@
 package WebService::HashiCorp::Vault;
 
 use Moo;
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 extends 'WebService::HashiCorp::Vault::Base';
 use namespace::clean;
 
 use WebService::HashiCorp::Vault::Secret::Cassandra;
+use WebService::HashiCorp::Vault::Secret::Cubbyhole;
 use WebService::HashiCorp::Vault::Secret::Generic;
 use WebService::HashiCorp::Vault::Secret::MongoDB;
 use WebService::HashiCorp::Vault::Secret::MSSQL;
 use WebService::HashiCorp::Vault::Secret::MySQL;
 use WebService::HashiCorp::Vault::Secret::PostgreSQL;
 use WebService::HashiCorp::Vault::Secret::RabbitMQ;
+use WebService::HashiCorp::Vault::Secret::SSH;
 use WebService::HashiCorp::Vault::Sys;
 
-sub BUILD {
-    my $self = shift;
-    $self->ua->default_header('X-Vault-Token' => $self->token);
-}
-
 
 {
 
     my %backendmap = (
         aws        => 'AWS',
         cassandra  => 'Cassandra',
+        cubbyhole  => 'Cubbyhole',
         consul     => 'Consul',
         cubbyhole  => 'Cubbyhole',
         generic    => 'Generic',
@@ -87,7 +85,7 @@ WebService::HashiCorp::Vault - Perl API for HashiCorp's Vault
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -109,8 +107,6 @@ A perl API for convenience in using HashiCorp's Vault server software.
 
 Vault secures, stores, and tightly controls access to tokens, passwords, certificates, API keys, and other secrets in modern computing. Vault handles leasing, key revocation, key rolling, and auditing. Through a unified API, users can access an encrypted Key/Value store and network encryption-as-a-service, or generate AWS IAM/STS credentials, SQL/NoSQL databases, X.509 certificates, SSH credentials, and more.
 
-=for Pod::Coverage BUILD
-
 =head1 ALPHA STATUS WARNING
 
 This API software is an Alpha release, which I am published for people to comment on and provide pull requests.
@@ -126,7 +122,7 @@ Unfortunatly the "official" API's for other languages aren't much to go on. They
 =head2 secret
 
  my $secret = $vault->secret(
-     mount => 'secret', # optional if mounted non-default
+     mount   => 'secret', # optional if mounted non-default
      backend => 'Generic', # or MySQL, or SSH, or whatever
  );
 
@@ -146,6 +142,8 @@ Here are the currently supported options:
 
 =item L<Cassandra|WebService::HashiCorp::Vault::Secret::Cassandra>
 
+=item L<Cubbyhole|WebService::HashiCorp::Vault::Secret::Cubbyhole>
+
 =item L<Generic|WebService::HashiCorp::Vault::Secret::Generic>
 
 =item L<MongoDB|WebService::HashiCorp::Vault::Secret::MongoDB>
@@ -158,6 +156,8 @@ Here are the currently supported options:
 
 =item L<RabbitMQ|WebService::HashiCorp::Vault::Secret::RabbitMQ>
 
+=item L<SSH|WebService::HashiCorp::Vault::Secret::SSH>
+
 =back
 
 =back
