@@ -9,7 +9,7 @@
 package WebService::HashiCorp::Vault::Base;
 
 use Moo;
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 use namespace::clean;
 
 with 'WebService::Client';
@@ -21,12 +21,17 @@ has mount => ( is => 'ro' );
 
 sub BUILD {
     my $self = shift;
-    $self->ua->default_header('X-Vault-Token' => $self->token);
+    $self->ua->default_header(
+        'X-Vault-Token' => $self->token,
+        'User_Agent'    => sprintf(
+            'WebService::HashiCorp::Vault %s (perl %s; %s)',
+            __PACKAGE__->VERSION,
+            $^V, $^O),
+    );
 }
 
 sub _mkuri {
     my $self = shift;
-    use Data::Dumper;
     my @paths = @_;
     return join '/',
         $self->base_url,
@@ -35,6 +40,26 @@ sub _mkuri {
         @paths
 }
 
+
+sub list {
+
+    my ($self, $path) = @_;
+
+    my $headers = $self->_headers();
+    my $url = $self->_url($path);
+
+    # HashiCorp have decided that 'LIST' is a http verb, so we must hack it in
+    my $req = HTTP::Request->new(
+        'LIST' => $url,
+        HTTP::Headers->new(%$headers)
+    );
+
+    # this is a WebService::Client internal function. I said hack!
+    return $self->req( $req );
+
+}
+
+
 1;
 
 __END__
@@ -49,7 +74,7 @@ WebService::HashiCorp::Vault::Base - Perl API for HashiCorp's Vault (Base)
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -111,6 +136,14 @@ Read-only one the object is created.
 
 The mount location of the resource. There is no default, but you should apply one in your class that builds upon this class.
 
+=head2 list
+
+ my $list = $obj->list('path');
+
+HashiCorp have decided that 'LIST' is a http verb, so we must hack it in.
+
+You can pretend this is now a normal part of L<WebService::Client> upon which this module is based.
+
 =head1 SEE ALSO
 
 L<WebService::HashiCorp::Vault>
