@@ -9,9 +9,8 @@
 package WebService::HashiCorp::Vault::Secret::Generic;
 
 use Moo;
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 use namespace::clean;
-use HTTP::Request;
 
 extends 'WebService::HashiCorp::Vault::Base';
 
@@ -73,16 +72,8 @@ sub _save {
 
 sub list {
     my $self = shift;
-    # HashiCorp have decided that 'LIST' is a http verb, so we must hack it in
-    my $request = HTTP::Request->new(
-        'LIST' => $self->_mkuri(
-            $self->path ? $self->path : ()
-        )
-    );
-    # this is a WebService::Client internal function. I said hack!
-    return $self->req(
-        $request
-    );
+    my $result = $self->SUPER::list( $self->_mkuri($self->path || ()) );
+    return $result->{data}
 }
 
 
@@ -100,7 +91,7 @@ WebService::HashiCorp::Vault::Secret::Generic - Perl API for HashiCorp's Vault (
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
